@@ -2,9 +2,11 @@ from argparse import Action
 from os import listdir
 from os import makedirs
 from os.path import isdir
+from os.path import isfile
 from os.path import join
 from os.path import sep
 from pathlib import Path
+import pandas as pd
 
 from pdf_play.helpers import utils
 
@@ -12,7 +14,6 @@ from pdf_play.helpers import utils
 class _WatermarkText(Action):
 
     def __call__(self, parser, namespace, values, option_string=None):
-        print('')
         setattr(namespace, self.dest, ' '.join(values))
 
 
@@ -66,8 +67,17 @@ class _OutputFileOTM(Action):
 class _WatermarkMTO(Action):
 
     def __call__(self, parser, namespace, values, option_string=None):
-        with open(values, 'r') as f:
-            setattr(namespace, self.dest, f.read().splitlines())
+        values_ = []
+        for value in values:
+            if isfile(value):
+                if value.endswith('.csv'):
+                    data = pd.read_csv(value)
+                else:
+                    data = pd.read_excel(value)
+                values_.extend(data.iloc[:, :2].values.tolist())
+                continue
+            values_.append(value)
+        setattr(namespace, self.dest, values_)
 
 
 target_file_oto = _TargetFileOTO
